(function(){'use strict';const FOCUSABLE_ELEMENTS = ['[href]:not([tabindex^="-"])', 'input:not([disabled]):not([type="hidden"]):not([tabindex^="-"]):not([type="radio"])', 'input[type="radio"]:checked', 'select:not([disabled]):not([tabindex^="-"])', 'textarea:not([disabled]):not([tabindex^="-"])', 'button:not([disabled]):not([tabindex^="-"])', '[tabindex]:not([tabindex^="-"])', '[contenteditable="true"]:not([tabindex^="-"])'];// Focus an element
// elements - array of dropdown elements
const focus = (elements, focussedIndex) => {
  // Use of % for infinite iterations
  var index = Math.abs(focussedIndex) % elements.length;
  if (index >= 0) {
    elements[index].focus();
  }
};

// Refocus trigger element
const refocusTrigger = (element) => {
  var dialogTrigger = element.querySelector('[x-spread="trigger"]');
  if (dialogTrigger) {
    dialogTrigger.focus();
  }
};

const adjustScrollBar = (isOpen) => {
  if (isOpen) {
    var htmlDocument = document.querySelector("html");
    htmlDocument.style.overflow = "hidden";
    var body = document.querySelector("body");
    body.style.paddingRight = getScrollbarWidth() + "px";
  } else {
    var htmlDocument = document.querySelector("html");
    htmlDocument.style.overflow = null;
    var body = document.querySelector("body");
    body.style.paddingRight = null;
  }
};

// Private
// From bootstrap
const getScrollbarWidth = () => {
  const scrollDiv = document.createElement("div");
  scrollDiv.className = "scrollbar-measure";
  document.body.appendChild(scrollDiv);
  const scrollbarWidth = scrollDiv.getBoundingClientRect().width - scrollDiv.clientWidth;
  document.body.removeChild(scrollDiv);
  return scrollbarWidth;
};// Data
var lastOpenedElement = null;

// Set attributes when the component is initialized
function init(drawer) {
  var trigger = drawer.querySelectorAll('[x-spread="trigger"]');
  if (trigger.length) {
    trigger = trigger[0];
    trigger.setAttribute("aria-haspopup", "dialog");
    var drawer = drawer.querySelectorAll('[x-spread="drawer"]');
    if (drawer.length) {
      drawer = drawer[0];
      drawer.setAttribute("role", "drawer");
      drawer.setAttribute("aria-hidden", true);
      drawer.setAttribute("aria-modal", true);
      drawer.setAttribute("tabindex", -1);
    }
  }
}

// Toggle aria atrributes based on the drawer state
function toggleAriaAtrributes(drawer, isOpen) {
  drawer = drawer.querySelectorAll('[x-spread="drawer"]');
  if (drawer.length) {
    drawer = drawer[0];
    if (isOpen) {
      drawer.setAttribute("aria-hidden", false);
    } else {
      drawer.setAttribute("aria-hidden", true);
    }
  }
}

// Initialize attribute for all drawer elements
var drawers = document.querySelectorAll('[x-data="drawer()"]');
drawers.forEach(function (drawer) {
  init(drawer);
});

window.drawer = function () {
  var focussedIndex = -1;
  return {
    open: false,
    trigger: {
      ["@click"]() {
        this.open = !this.open;
        if (this.open) {
          lastOpenedElement = this.$el;
          var drawer = this.$el.querySelector('[x-spread="drawer"]');
          var drawerElements = drawer.querySelectorAll(FOCUSABLE_ELEMENTS);
          focussedIndex++;
          focus(drawerElements, focussedIndex);
        } else {
          focussedIndex = -1;
        }
        adjustScrollBar(this.open);
        toggleAriaAtrributes(this.$el, this.open);
      },
      ["@keydown.escape"]() {
        this.open = false;
        focussedIndex = -1;
        refocusTrigger(lastOpenedElement);
        adjustScrollBar(this.open);
        toggleAriaAtrributes(this.$el, this.open);
      },
    },
    drawer: {
      ["x-show.transition.opacity.duration.100ms"]() {
        const drawerContent = this.$el.querySelector('[x-spread="drawer"]');
        if (this.open) {
          setTimeout(() => drawerContent.classList.add("active"), 100);
        } else {
          drawerContent.classList.remove("active");
        }
        return this.open;
      },
      ["@keydown.escape"]() {
        this.open = false;
        focussedIndex = -1;
        refocusTrigger(lastOpenedElement);
        adjustScrollBar(this.open);
        toggleAriaAtrributes(this.$el, this.open);
      },
      ["@keydown.tab"](e) {
        e.preventDefault();
        var drawer = this.$el.querySelector('[x-spread="drawer"]');
        var drawerElements = drawer.querySelectorAll(FOCUSABLE_ELEMENTS);
        focussedIndex++;
        focus(drawerElements, focussedIndex);
      },
      ["@click"](e) {
        if (this.open && e.target.hasAttribute("x-spread")) {
          this.open = false;
          focussedIndex = -1;
          refocusTrigger(lastOpenedElement);
          adjustScrollBar(this.open);
          toggleAriaAtrributes(this.$el, this.open);
        }
      },
    },
    close() {
      this.open = false;
      focussedIndex = -1;
      refocusTrigger(lastOpenedElement);
      adjustScrollBar(this.open);
      toggleAriaAtrributes(this.$el, this.open);
    },
  };
};}());